@@ -258,6 +258,9 @@ class Func(Expr):
         self.params = params
         super(Func, self).__init__()
 
+    def clone(self):
+        return Func(self.fn_name, *self.params)
+
 
 class _FN(object):
     def __getattr__(self, attr):
@@ -745,12 +748,12 @@ class QueryCompiler(object):
                 from_model = curr
                 to_model = join.model_class
 
-                field = from_model._meta.rel_for_model(to_model, join.column)
+                field = from_model._meta.rel_for_model(to_model, join.on)
                 if field:
                     left_field = field.db_column
                     right_field = to_model._meta.primary_key.db_column
                 else:
-                    field = to_model._meta.rel_for_model(from_model, join.column)
+                    field = to_model._meta.rel_for_model(from_model, join.on)
                     left_field = from_model._meta.primary_key.db_column
                     right_field = field.db_column
 
@@ -1027,7 +1030,7 @@ class QueryResultWrapper(object):
                 if not fk_field:
                     continue
 
-                if not joined_inst.get_id():
+                if not joined_inst.get_id() and fk_field.name in inst._data:
                     rel_inst_id = inst._data[fk_field.name]
                     joined_inst.set_id(rel_inst_id)
 
@@ -1087,7 +1090,7 @@ def not_allowed(fn):
     return inner
 
 
-Join = namedtuple('Join', ('model_class', 'join_type', 'column'))
+Join = namedtuple('Join', ('model_class', 'join_type', 'on'))
 
 class Query(object):
     require_commit = True
@@ -1454,6 +1457,7 @@ class DeleteQuery(Query):
 
 
 class Database(object):
+    commit_select = False
     compiler_class = QueryCompiler
     expr_overrides = {}
     field_overrides = {}
@@ -1526,7 +1530,11 @@ class Database(object):
 
     def execute(self, query):
         sql, params = query.sql(self.get_compiler())
-        return self.execute_sql(sql, params, query.require_commit)
+        if isinstance(query, (SelectQuery, RawQuery)):
+            commit = self.commit_select
+        else:
+            commit = query.require_commit
+        return self.execute_sql(sql, params, commit)
 
     def execute_sql(self, sql, params=None, require_commit=True):
         cursor = self.get_cursor()
@@ -1613,6 +1621,7 @@ class Database(object):
 class SqliteDatabase(Database):
     op_overrides = {
         OP_LIKE: 'GLOB',
+        OP_ILIKE: 'LIKE',
     }
 
     def _connect(self, database, **kwargs):
@@ -1631,6 +1640,7 @@ class SqliteDatabase(Database):
 
 
 class PostgresqlDatabase(Database):
+    commit_select = True
     field_overrides = {
         'bigint': 'BIGINT',
         'bool': 'BOOLEAN',
@@ -1956,10 +1966,10 @@ class Model(object):
         return cls.select().filter(*dq, **query)
 
     @classmethod
-    def get(cls, query=None, **kwargs):
+    def get(cls, *query, **kwargs):
         sq = cls.select().naive()
         if query:
-            sq = sq.where(query)
+            sq = sq.where(*query)
         if kwargs:
             sq = sq.filter(**kwargs)
         return sq.get()
@@ -2088,3 +2098,7 @@ def sort_models_topologically(models):
     for m in sorted(models, key=names, reverse=True):
         dfs(m)
     return list(reversed(ordering))  # want parents first in output ordering
+
+def raw_sql(query):
+    db = query.model_class._meta.database
+    return query.sql(db.get_compiler())
